hey there Snapstore is a key-value database system where every change to the databsase creates an entirely new snapshot of the state while minimizing space on disk.
Modules
Structs
Enums
Type Aliases
- Cache
Hash - Hash
AndContents - The return type when modifying the snapstore. You get the new top hash of the modified store, plus a list of all added paths. The added paths used for garbage collection.
- Hashed
- Item
- Key